@@ -16,7 +16,12 @@ from aiida import load_profile
 from optimade import __api_version__
 from optimade.server.config import CONFIG
 import optimade.server.exception_handlers as exc_handlers
-from optimade.server.middleware import EnsureQueryParamIntegrity
+from optimade.server.middleware import (
+    EnsureQueryParamIntegrity,
+    CheckWronglyVersionedBaseUrls,
+    HandleApiHint,
+    AddWarnings,
+)
 from optimade.server.routers import versions
 from optimade.server.routers.utils import BASE_URL_PREFIXES, mongo_id_for_database
 
@@ -43,6 +48,22 @@ LINKS_DATA = Path(__file__).parent.joinpath("data/links.json").resolve()
 with open(LINKS_DATA) as handle:
     data = json.load(handle)
 
+    if CONFIG.debug:
+        data.append(
+            {
+                "id": "local",
+                "type": "links",
+                "name": "Local server",
+                "description": (
+                    "Locally running instance of the AiiDA-OPTIMADE server using AiiDA"
+                    f" profile {PROFILE_NAME!r}."
+                ),
+                "base_url": "http://localhost:5000",
+                "homepage": "https://github.com/aiidateam/aiida-optimade",
+                "link_type": "child",
+            }
+        )
+
     processed = []
     for link in data:
         link["_id"] = {"$oid": mongo_id_for_database(link["id"], link["type"])}
@@ -75,6 +96,9 @@ APP = FastAPI(
 APP.add_middleware(CORSMiddleware, allow_origins=["*"])
 APP.add_middleware(EnsureQueryParamIntegrity)
 APP.add_middleware(RedirectOpenApiDocs)
+APP.add_middleware(CheckWronglyVersionedBaseUrls)
+APP.add_middleware(HandleApiHint)
+APP.add_middleware(AddWarnings)
 
 
 # Add various exception handlers
